<?php

namespace EventPortal\Domain\Agenda\Actions;

use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Agenda\SessionInput;
use EventPortal\Domain\Agenda\SessionOverlap;
use EventPortal\Domain\Form\Facades\Form;
use Illuminate\Support\Arr;

class UpdateSession
{
    public function execute(Session $session, Agenda $agenda, array $input = []): Session
    {
        $input = SessionInput::from($input)
            ->forceDate($agenda->date)
            ->formatForDatabase();

        $form = Form::make('session.update')
            ->model($session)
            ->context($session->pathway, $agenda)
            ->useAlternativeNames()
            ->validate($input);

        $overlaps = Session::query()
            ->where('id', '!=', $session->id)
            ->forPathway($session->pathway)
            ->completelyOverlaps($input['starting_at'], $input['ending_at'])
            ->exists();

        SessionOverlap::throwValidationExceptionIfOverlapping($form->getValidator(), $overlaps);

        if (Arr::has($input, 'event_speaker_id')) {
            $eventSpeakerIds = collect($input['event_speaker_id'])->pluck('value')->filter();
            $session->eventSpeakers()->sync($eventSpeakerIds);
        }

        return $form->handle($input)->getModel();
    }
}
