<?php

namespace EventPortal\Http\Controllers\Delegate\Event;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Event\Models\EventDelegate;
use EventPortal\Domain\Event\RegistrationCallToAction;
use EventPortal\Domain\Event\ValueObjects\EventDetails;
use EventPortal\Domain\Event\ValueObjects\PageHeader;
use EventPortal\Domain\Event\ValueObjects\UnableToAttendSection;
use EventPortal\Domain\Util\DelegateRender;
use EventPortal\Http\Controllers\Controller;
use Inertia\Response;

class LandingController extends Controller
{
    public function __invoke(Event $event): Response
    {
        $delegate = auth()->user()->delegate;
        $eventDelegate = EventDelegate::forEventAndDelegate($event, $delegate)->firstOrFail();

        $registrationCallToAction = RegistrationCallToAction::make()->forEventDelegate($eventDelegate);
        $unableToAttendSection = UnableToAttendSection::make()->forEventDelegate($eventDelegate);

        $pageHeader = PageHeader::make()
            ->title($event->name)
            ->description($event->snippet)
            ->callToAction($registrationCallToAction->asWhite()->get())
            ->heroImage(null);

        $eventDetails = EventDetails::make($event, $registrationCallToAction->notWhite()->getAsArray());

        $render = DelegateRender::component('Delegate/Landing/Index')
            ->withPageHeader($pageHeader)
            ->withEventDetails($eventDetails)
            ->withUnableToAttend($unableToAttendSection)
            ->withSpeakers($event->speakers)
            ->withVenues($event->venues);

        return $render->get();
    }
}
